@@ -164,7 +164,6 @@ public:
 	bool IsOperatorMultiply() const;
 	bool IsOperatorPower() const;
 	bool IsOperatorSequence() const;
-	virtual bool GenerateCode(Environment &env, Signal sig, Stream &stream);
 	virtual String ToString() const = 0;
 };
 
@@ -195,7 +194,6 @@ public:
 	Value ExecForList(Environment &env, Signal sig,
 							bool flattenFlag, bool evalSymFuncFlag) const;
 	void IncRef() const;
-	bool GenerateCode(Environment &env, Signal sig, Stream &stream);
 	String ToString(const char *sep = ", ") const;
 	void Accept(ExprVisitor &visitor) const;
 	bool IsContained(const Expr *pExpr) const;
@@ -294,7 +292,6 @@ public:
 	virtual Expr *MathDiff(Environment &env, Signal sig, const Symbol *pSymbol) const;
 	virtual Expr *MathOptimize(Environment &env, Signal sig) const;
 	virtual void Accept(ExprVisitor &visitor) const;
-	virtual bool GenerateCode(Environment &env, Signal sig, Stream &stream);
 	virtual String ToString() const;
 };
 
@@ -314,7 +311,6 @@ public:
 	virtual Expr *Clone() const;
 	virtual Value Exec(Environment &env, Signal sig) const;
 	virtual void Accept(ExprVisitor &visitor) const;
-	virtual bool GenerateCode(Environment &env, Signal sig, Stream &stream);
 	virtual String ToString() const;
 };
 
@@ -348,7 +344,6 @@ public:
 	inline const Symbol *GetSymbol() const { return _pSymbol; }
 	inline SymbolList &GetAttrFront() { return _attrFront; }
 	inline const SymbolList &GetAttrFront() const { return _attrFront; }
-	virtual bool GenerateCode(Environment &env, Signal sig, Stream &stream);
 	virtual String ToString() const;
 };
 
@@ -368,7 +363,6 @@ public:
 	virtual Expr *Clone() const;
 	virtual const char *GetPathName() const;
 	virtual Value Exec(Environment &env, Signal sig) const;
-	virtual bool GenerateCode(Environment &env, Signal sig, Stream &stream);
 	virtual String ToString() const;
 };
 
@@ -383,7 +377,6 @@ public:
 	virtual bool IsBlockParam() const;
 	virtual Expr *Clone() const;
 	virtual Value Exec(Environment &env, Signal sig) const;
-	virtual bool GenerateCode(Environment &env, Signal sig, Stream &stream);
 	virtual String ToString() const;
 };
 
@@ -401,7 +394,6 @@ public:
 	virtual Expr *Clone() const;
 	virtual Value Exec(Environment &env, Signal sig) const;
 	virtual void Accept(ExprVisitor &visitor) const;
-	virtual bool GenerateCode(Environment &env, Signal sig, Stream &stream);
 	virtual String ToString() const;
 	inline void SetParam(Expr_BlockParam *pExprBlockParam) {
 		_pExprBlockParam = pExprBlockParam;
@@ -425,7 +417,6 @@ public:
 	virtual Value Exec(Environment &env, Signal sig) const;
 	virtual Value DoAssign(Environment &env, Signal sig, Value &value,
 					const SymbolSet *pSymbolsAssignable, bool escalateFlag) const;
-	virtual bool GenerateCode(Environment &env, Signal sig, Stream &stream);
 	virtual String ToString() const;
 };
 
@@ -467,7 +458,6 @@ public:
 	virtual Value DoAssign(Environment &env, Signal sig, Value &value,
 					const SymbolSet *pSymbolsAssignable, bool escalateFlag) const;
 	virtual void Accept(ExprVisitor &visitor) const;
-	virtual bool GenerateCode(Environment &env, Signal sig, Stream &stream);
 	virtual String ToString() const;
 };
 
@@ -495,7 +485,6 @@ public:
 	virtual bool IsParentOf(const Expr *pExpr) const;
 	virtual Expr *MathDiff(Environment &env, Signal sig, const Symbol *pSymbol) const;
 	virtual Expr *MathOptimize(Environment &env, Signal sig) const;
-	virtual bool GenerateCode(Environment &env, Signal sig, Stream &stream);
 	virtual String ToString() const;
 	Value EvalEach(Environment &env, Signal sig, const Value &valueSelf,
 		Iterator *pIteratorSelf, bool listSelfFlag, const Function **ppFuncSuccRequester) const;
@@ -545,7 +534,6 @@ public:
 	virtual Expr *MathDiff(Environment &env, Signal sig, const Symbol *pSymbol) const;
 	virtual Expr *MathOptimize(Environment &env, Signal sig) const;
 	virtual bool IsUnaryOp() const;
-	virtual bool GenerateCode(Environment &env, Signal sig, Stream &stream);
 	virtual String ToString() const;
 };
 
@@ -567,7 +555,6 @@ public:
 	virtual Expr *MathDiff(Environment &env, Signal sig, const Symbol *pSymbol) const;
 	virtual Expr *MathOptimize(Environment &env, Signal sig) const;
 	virtual bool IsBinaryOp() const;
-	virtual bool GenerateCode(Environment &env, Signal sig, Stream &stream);
 	virtual String ToString() const;
 };
 
@@ -583,7 +570,6 @@ public:
 	virtual Value Exec(Environment &env, Signal sig) const;
 	virtual const Expr *Unquote() const;
 	virtual bool IsQuote() const;
-	virtual bool GenerateCode(Environment &env, Signal sig, Stream &stream);
 	virtual String ToString() const;
 };
 
@@ -598,7 +584,6 @@ public:
 	virtual Expr *Clone() const;
 	virtual Value Exec(Environment &env, Signal sig) const;
 	virtual bool IsForce() const;
-	virtual bool GenerateCode(Environment &env, Signal sig, Stream &stream);
 	virtual String ToString() const;
 };
 
@@ -618,7 +603,6 @@ public:
 	virtual Value Exec(Environment &env, Signal sig) const;
 	virtual bool IsPrefix() const;
 	inline const Symbol *GetSymbol() const { return _pSymbol; }
-	virtual bool GenerateCode(Environment &env, Signal sig, Stream &stream);
 	virtual String ToString() const;
 };
 
@@ -639,7 +623,6 @@ public:
 	virtual bool IsSuffix() const;
 	inline const Symbol *GetSymbol() const { return _pSymbol; }
 	OccurPattern GetOccurPattern() const;
-	virtual bool GenerateCode(Environment &env, Signal sig, Stream &stream);
 	virtual String ToString() const;
 };
 
@@ -660,7 +643,6 @@ public:
 				Environment &envDst, const SymbolSet *pSymbolsAssignable) const;
 	virtual Expr *Clone() const;
 	virtual bool IsAssign() const;
-	virtual bool GenerateCode(Environment &env, Signal sig, Stream &stream);
 	virtual String ToString() const;
 };
 
@@ -676,7 +658,6 @@ public:
 	virtual Value Exec(Environment &env, Signal sig) const;
 	virtual Expr *Clone() const;
 	virtual bool IsDictAssign() const;
-	virtual bool GenerateCode(Environment &env, Signal sig, Stream &stream);
 	virtual String ToString() const;
 	Value GetKey(Environment &env, Signal sig) const;
 };
@@ -705,7 +686,6 @@ public:
 	virtual Value DoAssign(Environment &env, Signal sig, Value &value,
 					const SymbolSet *pSymbolsAssignable, bool escalateFlag) const;
 	virtual bool IsField() const;
-	virtual bool GenerateCode(Environment &env, Signal sig, Stream &stream);
 	virtual String ToString() const;
 };
 
