@@ -287,16 +287,6 @@ public:
 	inline void SetMode(ResultMode resultMode, unsigned long flags) {
 		_resultMode = resultMode, _flags = flags;
 	}
-	inline bool IsRsltNormal() const { return _resultMode == RSLTMODE_Normal; }
-	inline bool IsRsltList() const { return _resultMode == RSLTMODE_List; }
-	inline bool IsRsltXList() const { return _resultMode == RSLTMODE_XList; }
-	inline bool IsRsltSet() const { return _resultMode == RSLTMODE_Set; }
-	inline bool IsRsltXSet() const { return _resultMode == RSLTMODE_XSet; }
-	inline bool IsRsltIterator() const { return _resultMode == RSLTMODE_Iterator; }
-	inline bool IsRsltXIterator() const { return _resultMode == RSLTMODE_XIterator; }
-	inline bool IsRsltVoid() const { return _resultMode == RSLTMODE_Void; }
-	inline bool IsRsltReduce() const { return _resultMode == RSLTMODE_Reduce; }
-	inline bool IsRsltXReduce() const { return _resultMode == RSLTMODE_XReduce; }
 	inline bool GetMapFlag() const { return (_flags & FLAG_Map)? true : false; }
 	inline bool GetFlatFlag() const { return (_flags & FLAG_Flat)? true : false; }
 	inline bool GetForkFlag() const { return (_flags & FLAG_Fork)? true : false; }
