@@ -25,7 +25,7 @@ public:
 	inline Option(const Info *infoTbl, int cntInfo) :
 									_infoTbl(infoTbl), _cntInfo(cntInfo) {}
 	~Option();
-	bool Parse(int &argc, const char *argv[], String &strErr);
+	bool Parse(Signal sig, int &argc, const char *argv[]);
 	bool IsSet(const char *key);
 	const char *GetString(const char *key, const char *defValue) const;
 	const StringList &GetStringList(const char *key) const;
