@@ -254,13 +254,9 @@ public:
 //-----------------------------------------------------------------------------
 class DLLDECLARE Value {
 public:
-	class KeyCompare {
-	private:
-		bool _ignoreCaseFlag;
-	public:
-		inline KeyCompare(bool ignoreCaseFlag = false) : _ignoreCaseFlag(ignoreCaseFlag) {}
+	struct KeyCompare {
 		inline bool operator()(const Value &value1, const Value &value2) const {
-			return Compare(value1, value2, _ignoreCaseFlag) < 0;
+			return Compare(value1, value2) < 0;
 		}
 	};
 private:
@@ -280,8 +276,6 @@ private:
 public:
 	static const Value Null;
 	static const Value Undefined;
-	static const KeyCompare KeyCompareCase;
-	static const KeyCompare KeyCompareIgnoreCase;
 public:
 	Value(const Value &value);
 	~Value();
@@ -527,7 +521,7 @@ public:
 	Object_Matrix *InitAsMatrix(Environment &env,
 								int nRows, int nCols, const Value &valueElem);
 	Object_Matrix *InitAsMatrix(Environment &env, Signal sig, const ValueList &valList);
-	ValueDict &InitAsDict(Environment &env, bool ignoreCaseFlag);
+	ValueDict &InitAsDict(Environment &env);
 	Object_Binary *InitAsBinary(Environment &env);
 	Object_Binary *InitAsBinary(Environment &env, const Binary &binary);
 	Object_Binary *InitAsBinary(Environment &env, const char *buff, size_t size);
@@ -537,7 +531,7 @@ public:
 	void InitAsIterator(Environment &env, Iterator *pIterator);
 	void InitAsEnvironment(Environment &env);
 public:
-	static int Compare(const Value &value1, const Value &value2, bool ignoreCaseFlag = false);
+	static int Compare(const Value &value1, const Value &value2);
 	inline bool operator<(const Value &value) const {
 		return Compare(*this, value) < 0;
 	}
@@ -614,19 +608,11 @@ typedef std::deque<Value> ValueDeque;
 //-----------------------------------------------------------------------------
 class DLLDECLARE ValueDict : public std::map<Value, Value, Value::KeyCompare> {
 public:
-	enum StoreMode {
-		STORE_Normal,
-		STORE_AllowDup,
-		STORE_Default,
-	};
 	static const ValueDict Null;
 public:
-	inline ValueDict() : std::map<Value, Value, Value::KeyCompare>() {}
-	inline ValueDict(const Value::KeyCompare &comp) :
-							std::map<Value, Value, Value::KeyCompare>(comp) {}
-	bool Store(Signal sig, const ValueList &valList, StoreMode storeMode);
-	bool Store(Signal sig, const ValueDict &valDict, StoreMode storeMode);
-	bool Store(Signal sig, const Value &valueIdx, const Value &value, StoreMode storeMode);
+	bool Store(Signal sig, const ValueList &valList, bool allowDupFlag);
+	bool Store(Signal sig, const ValueDict &valDict, bool allowDupFlag);
+	bool Store(Signal sig, const Value &valueIdx, const Value &value, bool allowDupFlag);
 	inline static bool IsValidKey(const Value &value) {
 		return value.IsNumber() || value.IsString() || value.IsSymbol();
 	}
