@@ -333,11 +333,6 @@ void Expr::SetError_NotAssignableSymbol(Signal sig, const Symbol *pSymbol) const
 		"symbol '%s' cannot be assigned in this object", pSymbol->GetName());
 }
 
-bool Expr::GenerateCode(Environment &env, Signal sig, Stream &stream)
-{
-	return false;
-}
-
 //-----------------------------------------------------------------------------
 // Expr::ExprVisitor_GatherSymbol
 //-----------------------------------------------------------------------------
@@ -551,12 +546,6 @@ void Expr_Value::Accept(ExprVisitor &visitor) const
 	visitor.Visit(this);
 }
 
-bool Expr_Value::GenerateCode(Environment &env, Signal sig, Stream &stream)
-{
-	stream.Println(sig, "Value");
-	return true;
-}
-
 String Expr_Value::ToString() const
 {
 	Signal sig;
@@ -596,12 +585,6 @@ void Expr_String::Accept(ExprVisitor &visitor) const
 	visitor.Visit(this);
 }
 
-bool Expr_String::GenerateCode(Environment &env, Signal sig, Stream &stream)
-{
-	stream.Println(sig, "String");
-	return true;
-}
-
 String Expr_String::ToString() const
 {
 	String str;
@@ -709,12 +692,6 @@ Expr *Expr_Symbol::MathOptimize(Environment &env, Signal sig) const
 	return Clone();
 }
 
-bool Expr_Symbol::GenerateCode(Environment &env, Signal sig, Stream &stream)
-{
-	stream.Println(sig, "Symbol");
-	return true;
-}
-
 String Expr_Symbol::ToString() const
 {
 	return GetSymbol()->GetName();
@@ -744,11 +721,6 @@ Value Expr_Root::Exec(Environment &env, Signal sig) const
 	return _exprOwner.ExecInRoot(env, sig);
 }
 
-bool Expr_Root::GenerateCode(Environment &env, Signal sig, Stream &stream)
-{
-	return _exprOwner.GenerateCode(env, sig, stream);
-}
-
 String Expr_Root::ToString() const
 {
 	return GetExprList().ToString();
@@ -794,12 +766,6 @@ void Expr_Block::Accept(ExprVisitor &visitor) const
 	Expr_Container::Accept(visitor);
 }
 
-bool Expr_Block::GenerateCode(Environment &env, Signal sig, Stream &stream)
-{
-	stream.Println(sig, "Block");
-	return true;
-}
-
 String Expr_Block::ToString() const
 {
 	String str;
@@ -833,12 +799,6 @@ Value Expr_BlockParam::Exec(Environment &env, Signal sig) const
 	return _exprOwner.Exec(env, sig, false);
 }
 
-bool Expr_BlockParam::GenerateCode(Environment &env, Signal sig, Stream &stream)
-{
-	stream.Println(sig, "BlockParam");
-	return true;
-}
-
 String Expr_BlockParam::ToString() const
 {
 	String str;
@@ -981,12 +941,6 @@ Value Expr_Lister::DoAssign(Environment &env, Signal sig, Value &value,
 	return value;
 }
 
-bool Expr_Lister::GenerateCode(Environment &env, Signal sig, Stream &stream)
-{
-	stream.Println(sig, "Lister");
-	return true;
-}
-
 String Expr_Lister::ToString() const
 {
 	String str;
@@ -1226,12 +1180,6 @@ void Expr_Indexer::Accept(ExprVisitor &visitor) const
 	}
 }
 
-bool Expr_Indexer::GenerateCode(Environment &env, Signal sig, Stream &stream)
-{
-	stream.Println(sig, "Indexer");
-	return true;
-}
-
 String Expr_Indexer::ToString() const
 {
 	String str;
@@ -1332,9 +1280,6 @@ Value Expr_Caller::DoExec(Environment &env, Signal sig,
 	if (valueSelf.IsInvalid()) return valueSelf;
 	Expr_Field::Mode mode = pExprField->GetMode();
 	if (mode != Expr_Field::MODE_Normal) {
-		if (valueSelf.IsList() && valueSelf.GetList().empty()) {
-			return valueSelf;
-		}
 		ObjectBase *pObj = valueSelf.ExtractObject(sig);
 		if (sig.IsSignalled()) {
 			sig.AddExprCause(this);
@@ -1512,16 +1457,6 @@ Expr *Expr_Caller::MathOptimize(Environment &env, Signal sig) const
 	return Clone();
 }
 
-bool Expr_Caller::GenerateCode(Environment &env, Signal sig, Stream &stream)
-{
-	stream.Println(sig, "Caller");
-	if (!_pExprCar->GenerateCode(env, sig, stream)) return false;
-	if (!GetExprList().GenerateCode(env, sig, stream)) return false;
-	if (_pExprBlock != NULL && _pExprBlock->GenerateCode(env, sig, stream)) return false;
-	if (_pExprCallerSucc != NULL && _pExprCallerSucc->GenerateCode(env, sig, stream)) return false;
-	return true;
-}
-
 String Expr_Caller::ToString() const
 {
 	String str;
@@ -1595,12 +1530,6 @@ Expr *Expr_UnaryOp::MathOptimize(Environment &env, Signal sig) const
 	return _func.OptimizeUnary(env, sig, pExprOpt);
 }
 
-bool Expr_UnaryOp::GenerateCode(Environment &env, Signal sig, Stream &stream)
-{
-	stream.Println(sig, "UnaryOp");
-	return true;
-}
-
 String Expr_UnaryOp::ToString() const
 {
 	bool needParenthesisFlag = false;
@@ -1663,12 +1592,6 @@ Expr *Expr_BinaryOp::MathOptimize(Environment &env, Signal sig) const
 	return _func.OptimizeBinary(env, sig, pExprOpt1, pExprOpt2);
 }
 
-bool Expr_BinaryOp::GenerateCode(Environment &env, Signal sig, Stream &stream)
-{
-	stream.Println(sig, "BinaryOp");
-	return true;
-}
-
 String Expr_BinaryOp::ToString() const
 {
 	bool needParenthesisFlag = false;
@@ -1730,12 +1653,6 @@ Value Expr_Quote::Exec(Environment &env, Signal sig) const
 	return value;
 }
 
-bool Expr_Quote::GenerateCode(Environment &env, Signal sig, Stream &stream)
-{
-	stream.Println(sig, "Quote");
-	return true;
-}
-
 String Expr_Quote::ToString() const
 {
 	String str;
@@ -1764,12 +1681,6 @@ Value Expr_Force::Exec(Environment &env, Signal sig) const
 	return result;
 }
 
-bool Expr_Force::GenerateCode(Environment &env, Signal sig, Stream &stream)
-{
-	stream.Println(sig, "Force");
-	return true;
-}
-
 String Expr_Force::ToString() const
 {
 	String str;
@@ -1798,12 +1709,6 @@ Value Expr_Prefix::Exec(Environment &env, Signal sig) const
 	return Value::Null;
 }
 
-bool Expr_Prefix::GenerateCode(Environment &env, Signal sig, Stream &stream)
-{
-	stream.Println(sig, "Prefix");
-	return true;
-}
-
 String Expr_Prefix::ToString() const
 {
 	String str;
@@ -1841,12 +1746,6 @@ OccurPattern Expr_Suffix::GetOccurPattern() const
 		OCCUR_Invalid;
 }
 
-bool Expr_Suffix::GenerateCode(Environment &env, Signal sig, Stream &stream)
-{
-	stream.Println(sig, "Suffix");
-	return true;
-}
-
 String Expr_Suffix::ToString() const
 {
 	String str;
@@ -1921,12 +1820,6 @@ Value Expr_Assign::Exec(Environment &env, Signal sig,
 	return GetLeft()->DoAssign(envDst, sig, value, pSymbolsAssignable, true);
 }
 
-bool Expr_Assign::GenerateCode(Environment &env, Signal sig, Stream &stream)
-{
-	stream.Println(sig, "Assign");
-	return true;
-}
-
 String Expr_Assign::ToString() const
 {
 	String str;
@@ -1972,12 +1865,6 @@ Value Expr_DictAssign::Exec(Environment &env, Signal sig) const
 	return result;
 }
 
-bool Expr_DictAssign::GenerateCode(Environment &env, Signal sig, Stream &stream)
-{
-	stream.Println(sig, "DictAssign");
-	return true;
-}
-
 String Expr_DictAssign::ToString() const
 {
 	String str;
@@ -2035,9 +1922,6 @@ Value Expr_Field::Exec(Environment &env, Signal sig) const
 	}
 	Mode mode = GetMode();
 	if (mode != MODE_Normal) {
-		if (valueSelf.IsList() && valueSelf.GetList().empty()) {
-			return valueSelf;
-		}
 		Iterator *pIterator = pObj->CreateIterator(sig);
 		if (sig.IsSignalled()) {
 			sig.AddExprCause(this);
@@ -2141,12 +2025,6 @@ Value Expr_Field::DoAssign(Environment &env, Signal sig, Value &value,
 	return value;
 }
 
-bool Expr_Field::GenerateCode(Environment &env, Signal sig, Stream &stream)
-{
-	stream.Println(sig, "Field");
-	return true;
-}
-
 String Expr_Field::ToString() const
 {
 	String str;
@@ -2276,14 +2154,6 @@ bool ExprList::IsContained(const Expr *pExpr) const
 	return std::find(begin(), end(), const_cast<Expr *>(pExpr)) != end();
 }
 
-bool ExprList::GenerateCode(Environment &env, Signal sig, Stream &stream)
-{
-	foreach_const (ExprList, ppExpr, *this) {
-		if (!(*ppExpr)->GenerateCode(env, sig, stream)) return false;
-	}
-	return true;
-}
-
 String ExprList::ToString(const char *sep) const
 {
 	String str;
