@@ -379,7 +379,7 @@ Value Function::EvalExpr(Environment &env, Signal sig, Args &args) const
 	const ExprList &exprListArg = args.GetExprListArg();
 	ValueList valListArg;
 	Value valueWithDict;
-	valueWithDict.InitAsDict(env, false);
+	valueWithDict.InitAsDict(env);
 	if (mapFlag && IsUnary() && (exprListArg.size() > 1 ||
 						!exprListArg.empty() && exprListArg.front()->IsSuffix())) {
 		if (!_declOwner.PrepareArgsForUnary(env, sig, exprListArg, valListArg, valueWithDict)) {
@@ -417,7 +417,6 @@ Value Function::EvalMap(Environment &env, Signal sig, Args &args) const
 	if (args.IsRsltIterator() || args.IsRsltXIterator()) {
 		// nothing to do
 	} else if (!args.IsRsltNormal() || !args.ShouldGenerateIterator(_declOwner)) {
-		// List, XList, Set, XSet, Void, Reduce, XReduce
 		return EvalMapRecursive(env, sig, NULL, args);
 	}
 	bool skipInvalidFlag = args.IsRsltXIterator();
@@ -519,7 +518,7 @@ Environment *Function::PrepareEnvironment(Environment &env, Signal sig, Args &ar
 	if (_declOwner.GetSymbolDict() != NULL) {
 		Value valueWithDict = args.GetValueWithDict();
 		if (valueWithDict.IsInvalid()) {
-			valueWithDict.InitAsDict(env, false);
+			valueWithDict.InitAsDict(env);
 		}
 		pEnvLocal->AssignValue(_declOwner.GetSymbolDict(), valueWithDict, false);
 	}
