@@ -423,50 +423,6 @@ Value Iterator::Or(Environment &env, Signal sig)
 	return Value(false);
 }
 
-size_t Iterator::Find(Environment &env, Signal sig, const Value &criteria)
-{
-	if (IsInfinite()) {
-		SetError_InfiniteNotAllowed(sig);
-		return InvalidSize;
-	}
-	size_t idx = 0;
-	if (criteria.IsFunction()) {
-		const Function *pFunc = criteria.GetFunction();
-		Value value;
-		while (Next(env, sig, value)) {
-			ValueList valListArg(value);
-			Args args(valListArg);
-			Value valueFlag = pFunc->Eval(env, sig, args);
-			if (sig.IsSignalled()) return InvalidSize;
-			if (valueFlag.GetBoolean()) return idx;
-			idx++;
-		}
-		if (sig.IsSignalled()) return InvalidSize;
-	} else {
-		Value value;
-		while (Next(env, sig, value)) {
-			if (Value::Compare(value, criteria) == 0) return idx;
-			idx++;
-		}
-	}
-	return InvalidSize;
-}
-
-size_t Iterator::FindTrue(Environment &env, Signal sig)
-{
-	if (IsInfinite()) {
-		SetError_InfiniteNotAllowed(sig);
-		return 0;
-	}
-	size_t idx = 0;
-	Value value;
-	while (Next(env, sig, value)) {
-		if (value.GetBoolean()) return idx;
-		idx++;
-	}
-	return InvalidSize;
-}
-
 size_t Iterator::Count(Environment &env, Signal sig, const Value &criteria)
 {
 	if (IsInfinite()) {
@@ -494,20 +450,6 @@ size_t Iterator::Count(Environment &env, Signal sig, const Value &criteria)
 	return cnt;
 }
 
-size_t Iterator::CountTrue(Environment &env, Signal sig)
-{
-	if (IsInfinite()) {
-		SetError_InfiniteNotAllowed(sig);
-		return 0;
-	}
-	size_t cnt = 0;
-	Value value;
-	while (Next(env, sig, value)) {
-		if (value.GetBoolean()) cnt++;
-	}
-	return cnt;
-}
-
 Iterator *Iterator::Filter(Environment &env, Signal sig, const Value &criteria)
 {
 	if (criteria.IsFunction()) {
@@ -646,7 +588,6 @@ void Iterator::Share::Store(int id, const Value &value)
 //-----------------------------------------------------------------------------
 Iterator_GenericClone::~Iterator_GenericClone()
 {
-	Iterator::Delete(_pIterator);
 }
 
 bool Iterator_GenericClone::DoNext(Environment &env, Signal sig, Value &value)
@@ -920,15 +861,7 @@ bool Iterator_Interval::DoNext(Environment &env, Signal sig, Value &value)
 
 String Iterator_Interval::ToString(Signal sig) const
 {
-	String str;
-	str = "<iterator:interval(";
-	str += NumberToString(_numBegin);
-	str += ",";
-	str += NumberToString(_numEnd);
-	str += ",";
-	str += NumberToString(_numSamples);
-	str += ")>";
-	return str;
+	return String("<iterator:interval>");
 }
 
 #if 0
@@ -1183,20 +1116,12 @@ bool Iterator_FuncBinder::DoNext(Environment &env, Signal sig, Value &value)
 		if (!_pFunc->GetDeclOwner().Compensate(_env, sig, valListComp)) {
 			return false;
 		}
-		Args args(valListComp, _valueSelf, NULL, false, &pFuncSuccRequester);
+		Args args(valListComp, Value::Null, NULL, false, &pFuncSuccRequester);
 		value = _pFunc->Eval(_env, sig, args);
 		if (sig.IsSignalled()) return false;
 	} else {
-		const Function *pFuncSuccRequester = NULL;
-		ValueList valListComp(valueArg);
-		if (!_pFunc->GetDeclOwner().Compensate(_env, sig, valListComp)) {
-			return false;
-		}
-		Args args(valListComp, _valueSelf, NULL, false, &pFuncSuccRequester);
-		value = _pFunc->Eval(_env, sig, args);
-		if (sig.IsSignalled()) return false;
-		//sig.SetError(ERR_TypeError, "invalid structure of arguments");
-		//return false;
+		sig.SetError(ERR_TypeError, "invalid structure of arguments");
+		return false;
 	}
 	return true;
 }
