@@ -218,7 +218,7 @@ AScript_DeclareFunction(parsestream)
 AScript_ImplementFunction(parsestream)
 {
 	Expr *pExpr = Parser().ParseStream(env, sig, args.GetStream(0));
-	if (pExpr == NULL) return Value::Null;
+	if (sig.IsSignalled()) return NULL;
 	return Value(env, pExpr);
 }
 
@@ -234,7 +234,7 @@ AScript_ImplementFunction(parse)
 {
 	const char *str = args.GetString(0);
 	Expr *pExpr = Parser().ParseString(env, sig, "<parse function>", str);
-	if (pExpr == NULL) return Value::Null;
+	if (sig.IsSignalled()) return Value::Null;
 	return Value(env, pExpr);
 }
 
@@ -1923,22 +1923,19 @@ AScript_ImplementFunction(MatrixInit)
 	return result;
 }
 
-// dict(elem[]?):[icase] {block?}, %{block}
+// dict(elem[]?) {block?}, %{block}
 AScript_DeclareFunction(dict)
 {
 	SetMode(RSLTMODE_Normal, FLAG_None);
 	DeclareArg(env, "elem", VTYPE_Any, OCCUR_ZeroOrOnce, true);
-	DeclareAttr(AScript_Symbol(icase));
 	DeclareBlock(OCCUR_ZeroOrOnce);
 }
 
 AScript_ImplementFunction(dict)
 {
-	Object_Dict *pObj = new Object_Dict(env, args.IsSet(AScript_Symbol(icase)));
+	Object_Dict *pObj = new Object_Dict(env);
 	ValueDict &valDict = pObj->GetDict();
-	ValueDict::StoreMode storeMode = ValueDict::STORE_Normal;
-	if (args.GetValue(0).IsList() &&
-					!valDict.Store(sig, args.GetList(0), storeMode)) {
+	if (args.GetValue(0).IsList() && !valDict.Store(sig, args.GetList(0), false)) {
 		return Value::Null;
 	}
 	if (args.IsBlockSpecified()) {
@@ -1948,7 +1945,7 @@ AScript_ImplementFunction(dict)
 		Value valueList =
 				pExprBlock->GetExprList().ExecForList(envLister, sig, false, false);
 		if (sig.IsSignalled() || !valueList.IsList()) return Value::Null;
-		if (!valDict.Store(sig, valueList.GetList(), storeMode)) return Value::Null;
+		if (!valDict.Store(sig, valueList.GetList(), false)) return Value::Null;
 	}
 	return Value(pObj);
 }
@@ -2007,30 +2004,19 @@ AScript_ImplementFunction(open)
 	return result;
 }
 
-// copy(src:stream, dst:stream, bytesunit:number => 65536):map:void {block?}
+// copy(src:stream, dst:stream):map:void
 AScript_DeclareFunction(copy)
 {
 	SetMode(RSLTMODE_Void, FLAG_Map);
 	DeclareArg(env, "src", VTYPE_Stream);
 	DeclareArg(env, "dst", VTYPE_Stream);
-	DeclareArg(env, "bytesunit", VTYPE_Number,
-					OCCUR_Once, false, false, new Expr_Value(65536));
-	DeclareBlock(OCCUR_ZeroOrOnce);
 }
 
 AScript_ImplementFunction(copy)
 {
 	Stream &streamSrc = args.GetStream(0);
 	Stream &streamDst = args.GetStream(1);
-	size_t bytesUnit = args.GetSizeT(2);
-	const Function *pFuncWatcher =
-					args.GetBlockFunc(env, sig, GetSymbolForBlock());
-	if (sig.IsSignalled()) return Value::Null;
-	if (bytesUnit == 0 || bytesUnit > 1024 * 1024) {
-		sig.SetError(ERR_ValueError, "wrong value for bytesunit");
-		return Value::Null;
-	}
-	streamSrc.ReadToStream(env, sig, streamDst, bytesUnit, pFuncWatcher);
+	streamSrc.ReadToStream(sig, streamDst);
 	return Value::Null;
 }
 
@@ -2065,12 +2051,11 @@ AScript_ImplementFunction(semaphore)
 	return Value(pObj);
 }
 
-// image(args+):map {block?}
+// image(args+):map
 AScript_DeclareFunction(image)
 {
 	SetMode(RSLTMODE_Normal, FLAG_Map);
 	DeclareArg(env, "args", VTYPE_Any, OCCUR_OnceOrMore);
-	DeclareBlock(OCCUR_ZeroOrOnce);
 	SetHelp(
 	"Returns an image object with specified characteristics. There are three patterns\n"
 	"to call the function as follows.\n"
@@ -2142,8 +2127,7 @@ AScript_ImplementFunction(image)
 		}
 		if (!pObj->Read(sig, stream, imgType)) return Value::Null;
 	}
-	Value result(pObj);
-	return ReturnValue(env, sig, args, result);
+	return Value(pObj);
 }
 
 // color(elem?, green:number => 0, blue:number => 0, alpha:number => 255)
