@@ -283,7 +283,7 @@ Value DecodeURIQuery(Environment &env, Signal sig, const char *str)
 	StringList stringList;
 	if (!DecodeURIQuery(sig, str, stringList)) return Value::Null;
 	Value result;
-	ValueDict &valDict = result.InitAsDict(env, true);
+	ValueDict &valDict = result.InitAsDict(env);
 	for (StringList::iterator pStr = stringList.begin();
 											pStr != stringList.end(); ) {
 		const String &key = *pStr++;
@@ -882,7 +882,7 @@ bool Header::SetFields(Signal sig, const ValueDict &valueDict, Stream *pStreamBo
 Value Header::GetFieldsAsDict(Environment &env) const
 {
 	Value result;
-	ValueDict &valueDict = result.InitAsDict(env, true);
+	ValueDict &valueDict = result.InitAsDict(env);
 	foreach_const (Dict, iterSrc, _dict) {
 		Value valueKey(env, iterSrc->first.c_str());
 		StringList *pStringList = iterSrc->second;
