@@ -726,7 +726,7 @@ AScript_ImplementPrivClass(Parser)
 // Object_Element
 //-----------------------------------------------------------------------------
 Object_Element::Object_Element(Environment &env, const char *name, const char **atts) :
-					Object_Dict(env.LookupClass(AScript_PrivVTYPE(Element)), false)
+						Object_Dict(env.LookupClass(AScript_PrivVTYPE(Element)))
 {
 	AssignValue(AScript_Symbol(name), Value(env, name), false);
 	if (atts != NULL) {
