@@ -70,7 +70,7 @@ private:
 	Value _valueKey;
 public:
 	inline Stocker_Mapping(Environment &env) :
-					_pObjDict(new Object_Dict(env, false)), _keyFlag(true) {}
+					_pObjDict(new Object_Dict(env)), _keyFlag(true) {}
 	virtual void Stock(const Value &value);
 	virtual Value GetValue();
 };
@@ -140,7 +140,6 @@ Iterator_FromStream::Iterator_FromStream(Signal sig, Stream *pStream) :
 
 Iterator_FromStream::~Iterator_FromStream()
 {
-	Stream::Delete(_pStream);
 	::yaml_parser_delete(&_parser);
 }
 
