@@ -313,24 +313,17 @@ void Object_Image::FillRect(size_t x, size_t y, size_t width, size_t height,
 void Object_Image::FillRectAlpha(size_t x, size_t y, size_t width, size_t height,
 		const Object_Color *pObjColor, unsigned char alphaKey, unsigned char alphaRest)
 {
+	unsigned char buff[8];
+	PutPixel(buff, pObjColor);
 	std::auto_ptr<Scanner> pScanner(CreateScanner(x, y, width, height));
-	if (pObjColor == NULL) {
-		do {
-			unsigned char *pPixel = pScanner->GetPointer();
+	do {
+		unsigned char *pPixel = pScanner->GetPointer();
+		if (::memcmp(pPixel, buff, 3) == 0) {
 			*(pPixel + OffsetAlpha) = alphaKey;
-		} while (pScanner->Next());
-	} else {
-		unsigned char buff[8];
-		PutPixel(buff, pObjColor);
-		do {
-			unsigned char *pPixel = pScanner->GetPointer();
-			if (::memcmp(pPixel, buff, 3) == 0) {
-				*(pPixel + OffsetAlpha) = alphaKey;
-			} else {
-				*(pPixel + OffsetAlpha) = alphaRest;
-			}
-		} while (pScanner->Next());
-	}
+		} else {
+			*(pPixel + OffsetAlpha) = alphaRest;
+		}
+	} while (pScanner->Next());
 }
 
 Object_Image *Object_Image::ReduceColor(Signal sig, const Object_Palette *pObjPalette)
@@ -1437,12 +1430,12 @@ AScript_ImplementMethod(Image, fillrect)
 	return Value::Null;
 }
 
-// image#setalpha(alphaKey:number, colorKey?:color, alphaRest:number => 255):reduce
+// image#setalpha(colorKey:color, alphaKey:number => 0, alphaRest:number => 255):reduce
 AScript_DeclareMethod(Image, setalpha)
 {
 	SetMode(RSLTMODE_Reduce, FLAG_None);
-	DeclareArg(env, "alphaKey", VTYPE_Number);
-	DeclareArg(env, "colorKey", VTYPE_Color, OCCUR_ZeroOrOnce);
+	DeclareArg(env, "colorKey", VTYPE_Color);
+	DeclareArg(env, "alphaKey", VTYPE_Number, OCCUR_Once, false, false, new Expr_Value(0));
 	DeclareArg(env, "alphaRest", VTYPE_Number, OCCUR_Once, false, false, new Expr_Value(255));
 }
 
@@ -1454,8 +1447,7 @@ AScript_ImplementMethod(Image, setalpha)
 		sig.SetError(ERR_ValueError, "only RGBA format contains alpha element");
 		return 0;
 	}
-	pSelf->FillAlpha(args.IsValid(1)? args.GetColorObj(1) : NULL,
-										args.GetUChar(0), args.GetUChar(2));
+	pSelf->FillAlpha(args.GetColorObj(0), args.GetUChar(1), args.GetUChar(2));
 	return args.GetSelf();
 }
 
