@@ -452,37 +452,18 @@ AScript_ImplementMethod(Iterator, reduce)
 	return result;
 }
 
-// iterator#find(criteria?)
-AScript_DeclareMethod(Iterator, find)
-{
-	SetMode(RSLTMODE_Normal, FLAG_None);
-	DeclareArg(env, "criteria", VTYPE_Any, OCCUR_ZeroOrOnce);
-}
-
-AScript_ImplementMethod(Iterator, find)
-{
-	Object_Iterator *pSelf = Object_Iterator::GetSelfObj(args);
-	Iterator *pIterator = pSelf->GetIterator()->Clone();
-	size_t idx = args.IsValid(0)?
-		pIterator->Find(env, sig, args.GetValue(0)) : pIterator->FindTrue(env, sig);
-	Iterator::Delete(pIterator);
-	if (idx == InvalidSize) return Value::Null;
-	return Value(static_cast<unsigned int>(idx));
-}
-
-// iterator#count(criteria?)
+// iterator#count(criteria)
 AScript_DeclareMethod(Iterator, count)
 {
 	SetMode(RSLTMODE_Normal, FLAG_None);
-	DeclareArg(env, "criteria", VTYPE_Any, OCCUR_ZeroOrOnce);
+	DeclareArg(env, "criteria", VTYPE_Any);
 }
 
 AScript_ImplementMethod(Iterator, count)
 {
 	Object_Iterator *pSelf = Object_Iterator::GetSelfObj(args);
 	Iterator *pIterator = pSelf->GetIterator()->Clone();
-	size_t cnt = args.IsValid(0)?
-		pIterator->Count(env, sig, args.GetValue(0)) : pIterator->CountTrue(env, sig);
+	size_t cnt = pIterator->Count(env, sig, args.GetValue(0));
 	Iterator::Delete(pIterator);
 	if (sig.IsSignalled()) return Value::Null;
 	return Value(static_cast<unsigned int>(cnt));
@@ -895,7 +876,6 @@ Class_Iterator::Class_Iterator(Environment *pEnvOuter) : Class(pEnvOuter)
 	AScript_AssignMethod(Iterator, since);
 	AScript_AssignMethod(Iterator, map);
 	AScript_AssignMethod(Iterator, reduce);
-	AScript_AssignMethod(Iterator, find);
 	AScript_AssignMethod(Iterator, count);
 	AScript_AssignMethod(Iterator, sort);
 	AScript_AssignMethod(Iterator, rank);
