@@ -1060,30 +1060,11 @@ AScript_ImplementMethod(List, reduce)
 	return result;
 }
 
-// list#find(criteria?)
-AScript_DeclareMethod(List, find)
-{
-	SetMode(RSLTMODE_Normal, FLAG_None);
-	DeclareArg(env, "criteria", VTYPE_Any, OCCUR_ZeroOrOnce);
-}
-
-AScript_ImplementMethod(List, find)
-{
-	Object_List *pSelf = Object_List::GetSelfObj(args);
-	Iterator *pIterator = pSelf->CreateIterator(sig);
-	if (sig.IsSignalled()) return Value::Null;
-	size_t idx = args.IsValid(0)?
-		pIterator->Find(env, sig, args.GetValue(0)) : pIterator->FindTrue(env, sig);
-	Iterator::Delete(pIterator);
-	if (idx == InvalidSize) return Value::Null;
-	return Value(static_cast<unsigned int>(idx));
-}
-
-// list#count(criteria?)
+// list#count(criteria)
 AScript_DeclareMethod(List, count)
 {
 	SetMode(RSLTMODE_Normal, FLAG_None);
-	DeclareArg(env, "criteria", VTYPE_Any, OCCUR_ZeroOrOnce);
+	DeclareArg(env, "criteria", VTYPE_Any);
 	SetHelp(
 	"Returns a number of elements that matches the given criteria which is a single-argument\n"
 	"function or a value. When a function is applied, it counts the number of true after\n"
@@ -1096,8 +1077,7 @@ AScript_ImplementMethod(List, count)
 	Object_List *pSelf = Object_List::GetSelfObj(args);
 	Iterator *pIterator = pSelf->CreateIterator(sig);
 	if (sig.IsSignalled()) return Value::Null;
-	size_t cnt = args.IsValid(0)?
-		pIterator->Count(env, sig, args.GetValue(0)) : pIterator->CountTrue(env, sig);
+	size_t cnt = pIterator->Count(env, sig, args.GetValue(0));
 	Iterator::Delete(pIterator);
 	if (sig.IsSignalled()) return Value::Null;
 	return Value(static_cast<unsigned int>(cnt));
@@ -1507,7 +1487,6 @@ Class_List::Class_List(Environment *pEnvOuter) : Class(pEnvOuter)
 	AScript_AssignMethod(List, since);
 	AScript_AssignMethod(List, map);
 	AScript_AssignMethod(List, reduce);
-	AScript_AssignMethod(List, find);
 	AScript_AssignMethod(List, count);
 	AScript_AssignMethod(List, sort);
 	AScript_AssignMethod(List, rank);
