@@ -616,7 +616,7 @@ Value Func_Multiply::EvalExpr(Environment &env, Signal sig, Args &args) const
 	const ExprList &exprListArg = args.GetExprListArg();
 	ValueList valListArg;
 	Value valueWithDict;
-	valueWithDict.InitAsDict(env, false);
+	valueWithDict.InitAsDict(env);
 	if (!_declOwner.PrepareArgs(env, sig, exprListArg, valListArg, valueWithDict)) {
 		return Value::Null;
 	}
@@ -641,21 +641,14 @@ Value Func_Multiply::EvalExpr(Environment &env, Signal sig, Args &args) const
 			Iterator *pIterator = valueRight.CreateIterator(sig);
 			if (sig.IsSignalled()) return Value::Null;
 			Iterator *pIteratorFuncBinder = new Iterator_FuncBinder(env,
-						Function::Reference(pFunc),
-						valueLeft.GetFunctionObj()->GetSelf(), pIterator);
+							Function::Reference(pFunc), Value::Null, pIterator);
 			return pIteratorFuncBinder->Eval(env, sig, argsSub);
 		} else if (valueRight.IsIterator()) {
 			Iterator *pIterator = valueRight.CreateIterator(sig);
 			if (sig.IsSignalled()) return Value::Null;
 			Iterator *pIteratorFuncBinder = new Iterator_FuncBinder(env,
-						Function::Reference(pFunc),
-						valueLeft.GetFunctionObj()->GetSelf(), pIterator);
-			if (pFunc->IsRsltNormal() ||
-						pFunc->IsRsltIterator() || pFunc->IsRsltXIterator()) {
-				return Value(env, pIteratorFuncBinder);
-			} else {
-				return pIteratorFuncBinder->Eval(env, sig, argsSub);
-			}
+							Function::Reference(pFunc), Value::Null, pIterator);
+			return Value(env, pIteratorFuncBinder);
 		}
 	} else if (valueLeft.IsMatrix() && valueRight.IsList() ||
 			   valueLeft.IsList() && valueRight.IsMatrix()) {
@@ -1109,7 +1102,7 @@ Value Func_Modulo::EvalExpr(Environment &env, Signal sig, Args &args) const
 	const ExprList &exprListArg = args.GetExprListArg();
 	ValueList valListArg;
 	Value valueWithDict;
-	valueWithDict.InitAsDict(env, false);
+	valueWithDict.InitAsDict(env);
 	if (!_declOwner.PrepareArgs(env, sig, exprListArg, valListArg, valueWithDict)) {
 		return Value::Null;
 	}
