@@ -36,8 +36,6 @@ ValueTypePool *ValueTypePool::_pInst = NULL;
 const Complex	Value::_compZero;
 const Value		Value::Null;
 const Value		Value::Undefined(VTYPE_Undefined, true);
-const Value::KeyCompare Value::KeyCompareCase(false);
-const Value::KeyCompare Value::KeyCompareIgnoreCase(true);
 const ValueList	ValueList::Null;
 const ValueMap	ValueMap::Null;
 const ValueDict	ValueDict::Null;
@@ -630,7 +628,7 @@ Number Value::ToNumber(bool allowPartFlag, bool &successFlag) const
 	}
 }
 
-int Value::Compare(const Value &value1, const Value &value2, bool ignoreCaseFlag)
+int Value::Compare(const Value &value1, const Value &value2)
 {
 	int rtn = -1;
 	if (value1.GetType() != value2.GetType()) {
@@ -646,11 +644,7 @@ int Value::Compare(const Value &value1, const Value &value2, bool ignoreCaseFlag
 		rtn = static_cast<int>(value1.GetSymbol()->GetUniqNum()) -
 										value2.GetSymbol()->GetUniqNum();
 	} else if (value1.IsString()) {
-		if (ignoreCaseFlag) {
-			rtn = ::strcasecmp(value1.GetString(), value2.GetString());
-		} else {
-			rtn = ::strcmp(value1.GetString(), value2.GetString());
-		}
+		rtn = ::strcmp(value1.GetString(), value2.GetString());
 	} else if (value1.IsDateTime()) {
 		const DateTime &dt1 = value1.GetDateTime();
 		const DateTime &dt2 = value2.GetDateTime();
@@ -755,9 +749,9 @@ ValueList &Value::InitAsList(Environment &env, size_t n, const Value &value)
 	return pObj->GetList();
 }
 
-ValueDict &Value::InitAsDict(Environment &env, bool ignoreCaseFlag)
+ValueDict &Value::InitAsDict(Environment &env)
 {
-	Object_Dict *pObj = new Object_Dict(env, ignoreCaseFlag);
+	Object_Dict *pObj = new Object_Dict(env);
 	InitAsObject(pObj);
 	return pObj->GetDict();
 }
@@ -925,7 +919,7 @@ bool ValueList::ToStringList(Signal sig, StringList &strList) const
 //-----------------------------------------------------------------------------
 // ValueDict
 //-----------------------------------------------------------------------------
-bool ValueDict::Store(Signal sig, const ValueList &valList, StoreMode storeMode)
+bool ValueDict::Store(Signal sig, const ValueList &valList, bool allowDupFlag)
 {
 	enum { FIELD_Key, FIELD_Value } field = FIELD_Key;
 	Value valueIdx;
@@ -954,10 +948,8 @@ bool ValueDict::Store(Signal sig, const ValueList &valList, StoreMode storeMode)
 				ValueDict::iterator iterDst = find(valueIdx);
 				if (iterDst == end()) {
 					insert(ValueDict::value_type(valueIdx, value));
-				} else if (storeMode == STORE_AllowDup) {
+				} else if (allowDupFlag) {
 					iterDst->second = value;
-				} else if (storeMode == STORE_Default) {
-					// nothing to do
 				} else {
 					sig.SetError(ERR_KeyError, "duplicated key '%s'", valueIdx.ToString(sig).c_str());
 					return false;
@@ -969,10 +961,8 @@ bool ValueDict::Store(Signal sig, const ValueList &valList, StoreMode storeMode)
 			ValueDict::iterator iterDst = find(valueIdx);
 			if (iterDst == end()) {
 				insert(ValueDict::value_type(valueIdx, *pValue));
-			} else if (storeMode == STORE_AllowDup) {
+			} else if (allowDupFlag) {
 				iterDst->second = *pValue;
-			} else if (storeMode == STORE_Default) {
-				// nothing to do
 			} else {
 				sig.SetError(ERR_KeyError, "duplicated key '%s'", valueIdx.ToString(sig).c_str());
 				return false;
@@ -987,17 +977,15 @@ bool ValueDict::Store(Signal sig, const ValueList &valList, StoreMode storeMode)
 	return true;
 }
 
-bool ValueDict::Store(Signal sig, const ValueDict &valDict, StoreMode storeMode)
+bool ValueDict::Store(Signal sig, const ValueDict &valDict, bool allowDupFlag)
 {
 	foreach_const (ValueDict, iterSrc, valDict) {
 		const Value &valueIdx = iterSrc->first;
 		ValueDict::iterator iterDst = find(valueIdx);
 		if (iterDst == end()) {
 			insert(*iterSrc);
-		} else if (storeMode == STORE_AllowDup) {
+		} else if (allowDupFlag) {
 			iterDst->second = iterSrc->second;
-		} else if (storeMode == STORE_Default) {
-			// nothing to do
 		} else {
 			sig.SetError(ERR_KeyError, "duplicated key '%s'", valueIdx.ToString(sig).c_str());
 			return false;
@@ -1006,23 +994,16 @@ bool ValueDict::Store(Signal sig, const ValueDict &valDict, StoreMode storeMode)
 	return true;
 }
 
-bool ValueDict::Store(Signal sig, const Value &valueIdx, const Value &value, StoreMode storeMode)
+bool ValueDict::Store(Signal sig, const Value &valueIdx, const Value &value, bool allowDupFlag)
 {
 	if (!ValueDict::IsValidKey(valueIdx)) {
 		sig.SetError(ERR_KeyError, "invalid value type for key");
 		return false;
-	}
-	ValueDict::iterator iterDst = find(valueIdx);
-	if (iterDst == end()) {
-		insert(ValueDict::value_type(valueIdx, value));
-	} else if (storeMode == STORE_AllowDup) {
-		iterDst->second = value;
-	} else if (storeMode == STORE_Default) {
-		// nothing to do
-	} else {
+	} else if (!allowDupFlag && find(valueIdx) != end()) {
 		sig.SetError(ERR_KeyError, "duplicated key '%s'", valueIdx.ToString(sig).c_str());
 		return false;
 	}
+	insert(ValueDict::value_type(valueIdx, value));
 	return true;
 }
 
